@@ -3,7 +3,7 @@ BEGIN {
   $POE::Component::IRC::Plugin::Logger::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::Logger::VERSION = '6.47';
+  $POE::Component::IRC::Plugin::Logger::VERSION = '6.48';
 }
 
 use strict;
@@ -100,10 +100,11 @@ sub S_333 {
 
 sub S_chan_mode {
     my ($self, $irc) = splice @_, 0, 2;
+    pop @_;
     my $nick = parse_user(${ $_[0] });
     my $chan = irc_to_utf8(${ $_[1] });
     my $mode = ${ $_[2] };
-    my $arg  = ${ $_[3] };
+    my $arg  = defined $_[3] ? ${ $_[3] } : '';
 
     $self->_log_entry($chan, $mode => $nick, $arg);
     return PCI_EAT_NONE;
